/**
 * P4
 * http://snarfed.org/space/p4
 *
 * Copyright 2001-2004
 * Ken Ashcraft <kashcraft+p4@gmail.com>
 * Ryan Barrett <p4@ryanb.org>
 * Maulik Shah <p4@maulik.net>
 * Nathan Stoll <nathanstoll+p4@gmail.com>
 *
 * @file msg_ping.h
 *
 * Defines the cmsg_ping class, which is derived from the abstract cmsg class.
 * The cmsg_ping class is the class that PING messages instantiate. For more
 * information, see protocol.txt, msg.h, and protocol.h.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef _MSG_PING_H
#define _MSG_PING_H

#include "protocol.h"
#include "msg.h"


/*****************************************************************************
 * FORWARD DECLARATIONS
 *****************************************************************************/
class cmsg_factory;  // so that we can declare it as a friend


/*****************************************************************************
 * CMSG_PING CLASS
 *****************************************************************************/

class cmsg_ping : public cmsg {
  public:

  /** ctor
   */
  cmsg_ping() : cmsg(0, 0, 0)  { hdr.set_type(kp4_ping); }

  /** dtor
   */
  virtual ~cmsg_ping() {} 

  /** send
   *
   * PING messages are sent direct, so the send methods are made public.
   */
  virtual const cconn &send(const string &username)
    { return cmsg::send(username); }

  protected:
  friend class cmsg_factory;  // for constructing from a p4 header

  /** ctors
   */
  cmsg_ping(const p4_header &hdr) : cmsg(hdr) {}
  cmsg_ping(const cmsg &msg) : cmsg(msg) {}

  /** virt_process
   *
   * For a PING message, virt_process responds with a PING_ACK message.
   */
  virtual bool virt_process() const;
};


#endif  // _MSG_PING_H
